@@ -12,9 +12,6 @@ def pytest_addoption(parser):
     """
     adds the option to write --file=<your path to connector.py>
     """
-    parser.addoption("--lib-path", action="store", default="absolute path to the conftest file from the root of the "
-                                                           "project")
-    parser.addoption("--env", action="store", default="absolute path to the env that holds the variables used to test")
     parser.addoption(
         "--source", action="store_true", default=False, help="run source tests"
     )
@@ -204,3 +201,10 @@ def get_good_data_small(connector, good_object_id, get_all_good_field_ids):
     # Since we are using a test account, we should have made some data for the selected object_id
     data = connector.get_data(object_id=good_object_id, field_ids=get_all_good_field_ids, n_rows=5)
     return data
+
+
+@pytest.fixture(scope="session")
+def get_good_meta_data(connector):
+    connector.authenticate()
+    meta = connector.get_meta_data()
+    return meta
