@@ -25,14 +25,6 @@ class TestAuth:
         results = good_authentication
         assert results
 
-    @pytest.mark.source
-    @pytest.mark.destination
-    @pytest.mark.authenticate
-    def test_fail_raises_bad_credentials_error(self, connector_class, bad_credentials):
-        _connector = connector_class.Connector(bad_credentials)
-        with pytest.raises(errors.BadCredentialsError):
-            _connector.authenticate()
-
     @pytest.mark.source
     @pytest.mark.destination
     @pytest.mark.authenticate
@@ -265,7 +257,7 @@ class TestGetData:
     @pytest.mark.get_data
     def test_pass_returns_next_page_flag(self, get_good_data_small):
         data = get_good_data_small
-        assert "next_page_flag" in data
+        assert "next_page" in data
 
 
 class TestGetMetaData:
